Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(31)

Unified Diff: pkg/analysis_server/lib/src/services/completion/invocation_computer.dart

Issue 1060713005: rename completion computer to contributor (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: merge Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/lib/src/services/completion/invocation_computer.dart
diff --git a/pkg/analysis_server/lib/src/services/completion/invocation_computer.dart b/pkg/analysis_server/lib/src/services/completion/invocation_computer.dart
index 540b32d340cd45d8180b9cadc455159e82be8222..d31d3d19922dcd69ef223b6e6d365168403a7452 100644
--- a/pkg/analysis_server/lib/src/services/completion/invocation_computer.dart
+++ b/pkg/analysis_server/lib/src/services/completion/invocation_computer.dart
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-library services.completion.computer.dart.invocation;
+library services.completion.contributor.dart.invocation;
import 'dart:async';
@@ -16,10 +16,10 @@ import 'package:analyzer/src/generated/element.dart';
import '../../protocol_server.dart' show CompletionSuggestionKind;
/**
* A computer for calculating invocation / access suggestions
* `completion.getSuggestions` request results.
*/
-class InvocationComputer extends DartCompletionComputer {
+class PrefixedElementContributor extends DartCompletionContributor {
SuggestionBuilder builder;
@override

Powered by Google App Engine
This is Rietveld 408576698
@@ -16,10 +16,10 @@ import 'package:analyzer/src/generated/element.dart';
import '../../protocol_server.dart' show CompletionSuggestionKind;
/**
- * A computer for calculating invocation / access suggestions
+ * A contributor for calculating invocation / access suggestions
* `completion.getSuggestions` request results.
*/